from django.db.models.loading import get_model
from django.http import JsonResponse


def filter_models(request):
    model_name = request.GET.get('model')
    search_field = request.GET.get('search_field')
    value = request.GET.get('q')

    model = get_model(model_name)
    print {'{}__icontains'.format(search_field): value}

    values = model.objects.filter(**{'{}__icontains'.format(search_field): value})[:10]
    values = [
        dict(id=value.id, name=unicode(value))
        for value
        in values
    ]

    return JsonResponse(dict(result=values))



from django import forms
from django.db.models.loading import get_model
from django.template.loader import render_to_string


class SearchableSelect(forms.CheckboxSelectMultiple):
    class Media:
        css = {
            'all': (
                'searchableselect/main.css',
            )
        }
        js = (
            'searchableselect/bloodhound.min.js',
            'searchableselect/typeahead.jquery.min.js',
            'searchableselect/main.js',
        )

    def __init__(self, *args, **kwargs):
        self.model = kwargs.pop('model')
        self.search_field = kwargs.pop('search_field')

        super(SearchableSelect, self).__init__(*args, **kwargs)

    def render(self, name, value, attrs=None, choices=()):
        if value is None:
            value = []

        values = get_model(self.model).objects.filter(pk__in=value)

        final_attrs = self.build_attrs(attrs, name=name)

        return render_to_string('searchableselect/select.html', dict(
            field_id=final_attrs['id'],
            field_name=final_attrs['name'],
            values=values,
            model=self.model,
            search_field=self.search_field
        ))



import os
from setuptools import setup

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
readme = f.read()
f.close()

setup(
    name='django-searchable-select',
    version='0.1',
    description='django-searchable-select - a better and faster multiple selection widget with suggestions',
    long_description=readme,
    author="Andrew Dunai",
    author_email='andrew@dun.ai',
    url='https://github.com/and3rson/django-searchable-select',
    license='GPLv2',
    packages=['searchable-select'],
    include_package_data=True,
    install_requires=['setuptools', 'django'],
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    keywords='django,admin,suit,select,multiple,faster,choice',
)
